
/*
TASK: boxes
LANG: C++
*/

#include <cstdio>
#include <cstring>
#include <algorithm>
using namespace std;

const int MAX_N = 100000 + 5;

int N;
int mark[MAX_N];
int dst[MAX_N];
int prev_edge[MAX_N];
int last_edge[MAX_N];

inline void add_edge(int id, int u, int v) {
    dst[id] = v;
    prev_edge[id] = last_edge[u];
    last_edge[u] = id;
}

void read() {
    memset(last_edge, -1, sizeof(int) * N);
    for (int i = 0; i < N; ++i) {
        int at;
        scanf("%d", &at); --at;
        add_edge(i, at, i);
    }
}

int brute() { // Try each subset of the verticies. O(n * 2 ^ n)
    int res = N;
    for (int set = 0; set < (1 << N); ++set) {
        int all = 0;
        int cnt = 0;
        for (int i = 0; i < N; ++i)
            if (((set >> i) & 1) > 0) {
                ++cnt;
                all |= 1 << i;
                for (int j = last_edge[i]; j != -1; j = prev_edge[j])
                    all |= 1 << dst[j];
            }
        if (all == (1 << N) - 1)
            res = min(res, __builtin_popcount(set));
    }
    return res;
}

int root = -1;

int dfs(int at) { // Stack overflow?
    if (root == at) {
        mark[at] = 2;
    } else {
        if (mark[at] == 2) {
            mark[at] = 1;
//            printf("Unmarking node %d\n", at);
            return 1;
        } else if (mark[at] == 1) {
            return 0;
        } else {
            mark[at] = 1;
        }
    }
    int res = 0;
    for (int j = last_edge[at]; j != -1; j = prev_edge[j])
        if (dst[j] != at)
            res += dfs(dst[j]);
    return res;
}

int solve() { // Greedy approach. O(n)
    static int q[MAX_N];  
    memset(mark, 0, sizeof(int) * N);
    int cnt = 0;
    for (int i = 0; i < N; ++i)
        if (!mark[i]) {
            ++cnt;
            
            int qh = 0;
            int qt = 1;
            q[qh] = i;
            mark[i] = 2;
            while (qh < qt) {
                int at = q[qh++];
                for (int j = last_edge[at]; j != -1; j = prev_edge[j])
                    switch (mark[dst[j]]) {
                        case 2:
                            if (dst[j] != i) {
                                mark[dst[j]] = 1;
                                --cnt;
                            }
                            break;

                        case 1:
                            break;

                        case 0:
                            mark[dst[j]] = 1;
                            q[qt++] = dst[j];
                            break;
                    }
            }

            //root = i;
            //cnt -= dfs(i);
//            mark[i] = 2; // means this should be broken
//            printf("roots = %d | ", cnt);
//            for (int j = 0; j < N; ++j)
//                printf("%d ", mark[j]);
//            puts("");
        }
    return cnt;
}

int main() {
    scanf("%d", &N);
    for (int i = 0; i < 2; ++i) {
        if (i > 0)
            printf(" ");
        read();
        printf("%d", solve());
//        puts("");
    }
    puts("");
    return 0;
}
